///////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2004 Intel Corporation 
// All rights reserved. 
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions are met: 
//
// * Redistributions of source code must retain the above copyright notice, 
// this list of conditions and the following disclaimer. 
// * Redistributions in binary form must reproduce the above copyright notice, 
// this list of conditions and the following disclaimer in the documentation 
// and/or other materials provided with the distribution. 
// * Neither name of Intel Corporation nor the names of its contributors 
// may be used to endorse or promote products derived from this software 
// without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR 
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
// OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
///////////////////////////////////////////////////////////////////////////

//
// DFT.cpp : Calculate and display DFT
//

#include "stdafx.h"
#include "ipp.h"
#include "tools.h"

// Calculate FFT and extend CCS representation to full signal
void myDFT_RToC_32f32fc(Ipp32f* pSrc, Ipp32fc*pDst, int len)
{
	IppsDFTSpec_R_32f *pDFTSpec;
	ippsDFTInitAlloc_R_32f( &pDFTSpec, len, IPP_FFT_DIV_INV_BY_N,
		ippAlgHintFast );
	ippsDFTFwd_RToCCS_32f(pSrc, (Ipp32f*)pDst, pDFTSpec, 0 );
	ippsConjCcs_32fc_I(pDst, len);
	ippsDFTFree_R_32f(pDFTSpec);
}

int main(int argc, char* argv[])
{
	int len;
	Ipp32f* pSrc;
	Ipp32fc* pDst;
	Ipp32f* pDstMag;

	for (len=4; len<= 8192; len*=2)
	{
		// Generate a Jaehne signal as source for FFT
		pSrc = ippsMalloc_32f(len);
		pDst = ippsMalloc_32fc(len);
		pDstMag = ippsMalloc_32f(len);
		ippsVectorJaehne_32f( pSrc, len, 1 );

		// Take DFT, calculate magnitude, and display
		myDFT_RToC_32f32fc(pSrc, pDst, len);
		ippsMagnitude_32fc(pDst, pDstMag, len);
		spView_32f( pDstMag,len,"DFT(Source)", 1 );

		ippsFree(pDst);
		ippsFree(pSrc);
		ippsFree(pDstMag);
	}

	return 0;
}

